@@ -8,7 +8,6 @@ class MongodbClient(AbstractClient):
     _apiVersion = '2017-01-01'
     _endpoint = 'mongodb.api.ksyun.com'
     _service = 'mongodb'
-
     def CreateMongoDBInstance(self, request):
         """创建副本集实例
         :param request: Request instance for CreateMongoDBInstance.
@@ -29,10 +28,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteMongoDBInstance(self, request):
-        """删除实例
+        """删除实例。
         :param request: Request instance for DeleteMongoDBInstance.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DeleteMongoDBInstanceRequest`
         """
@@ -51,7 +51,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeMongoDBInstance(self, request):
         """查询实例详情
@@ -60,7 +61,7 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call_judge("DescribeMongoDBInstance", params, "application/json")
+            body = self.call_judge("DescribeMongoDBInstance", params, "application/x-www-form-urlencoded")
             response = json.loads(body)
             if "Error" not in response:
                 return body
@@ -73,10 +74,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeMongoDBInstances(self, request):
-        """查询账号下实例列表
+        """查询实例列表
         :param request: Request instance for DescribeMongoDBInstances.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeMongoDBInstancesRequest`
         """
@@ -95,7 +97,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeMongoDBInstanceNode(self, request):
         """查询副本集实例节点信息
@@ -117,7 +120,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def RenameMongoDBInstance(self, request):
         """实例重命名
@@ -139,10 +143,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def ResetPasswordMongoDBInstance(self, request):
-        """修改密码
+        """修改实例密码
         :param request: Request instance for ResetPasswordMongoDBInstance.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.ResetPasswordMongoDBInstanceRequest`
         """
@@ -161,10 +166,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def RestartMongoDBInstance(self, request):
-        """重启实例
+        """重启实例。
         :param request: Request instance for RestartMongoDBInstance.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.RestartMongoDBInstanceRequest`
         """
@@ -183,10 +189,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def CreateMongoDBSnapshot(self, request):
-        """创建手动备份
+        """手动创建备份
         :param request: Request instance for CreateMongoDBSnapshot.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.CreateMongoDBSnapshotRequest`
         """
@@ -205,7 +212,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def SetMongoDBTimingSnapshot(self, request):
         """自动备份设置
@@ -227,7 +235,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeMongoDBSnapshot(self, request):
         """查询实例备份记录列表
@@ -236,7 +245,7 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call_judge("DescribeMongoDBSnapshot", params, "application/json")
+            body = self.call_judge("DescribeMongoDBSnapshot", params, "application/x-www-form-urlencoded")
             response = json.loads(body)
             if "Error" not in response:
                 return body
@@ -249,16 +258,17 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteMongoDBSnapshot(self, request):
-        """删除备份
+        """删除备份。
         :param request: Request instance for DeleteMongoDBSnapshot.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DeleteMongoDBSnapshotRequest`
         """
         try:
             params = request._serialize()
-            body = self.call_judge("DeleteMongoDBSnapshot", params, "application/json")
+            body = self.call_judge("DeleteMongoDBSnapshot", params, "application/x-www-form-urlencoded")
             response = json.loads(body)
             if "Error" not in response:
                 return body
@@ -271,10 +281,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def RenameMongoDBSnapshot(self, request):
-        """备份重命名
+        """修改备份名称
         :param request: Request instance for RenameMongoDBSnapshot.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.RenameMongoDBSnapshotRequest`
         """
@@ -293,7 +304,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def AddSecurityGroupRule(self, request):
         """添加安全组规则
@@ -315,7 +327,31 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
+
+    def DeleteSecurityGroupRules(self, request):
+        """删除安全组规则
+        :param request: Request instance for DeleteSecurityGroupRules.
+        :type request: :class:`ksyun.client.mongodb.v20170101.models.DeleteSecurityGroupRulesRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("DeleteSecurityGroupRules", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(message=str(e))
+
 
     def ListSecurityGroupRules(self, request):
         """查询安全组列表
@@ -337,7 +373,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def UpdateMongoDBInstance(self, request):
         """副本集实例更配
@@ -359,7 +396,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def AddSecondaryInstance(self, request):
         """副本集实例添加secondary节点
@@ -381,10 +419,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeMongoDBShardNode(self, request):
-        """分片集群实例shard节点查询
+        """查询分片集群实例shard节点信息
         :param request: Request instance for DescribeMongoDBShardNode.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeMongoDBShardNodeRequest`
         """
@@ -403,10 +442,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeValidRegion(self, request):
-        """查询用户可用机房详情
+        """查询用户可用机房列表
         :param request: Request instance for DescribeValidRegion.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeValidRegionRequest`
         """
@@ -425,7 +465,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def AllocateEip(self, request):
         """实例绑定外网eip
@@ -447,7 +488,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeallocateEip(self, request):
         """实例解绑外网eip
@@ -469,7 +511,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeRegions(self, request):
         """查询机房可用区
@@ -491,7 +534,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def CreateMongoDBShardInstance(self, request):
         """创建分片集群实例
@@ -513,10 +557,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DownloadSnapshot(self, request):
-        """下载备份
+        """下载备份。
         :param request: Request instance for DownloadSnapshot.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DownloadSnapshotRequest`
         """
@@ -535,7 +580,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def CloneInstance(self, request):
         """基于备份文件恢复至新实例
@@ -557,10 +603,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeShardNode(self, request):
-        """查询分片集群shard节点列表
+        """查询分片集群shard节点信息
         :param request: Request instance for DescribeShardNode.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeShardNodeRequest`
         """
@@ -579,10 +626,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeInstanceStatistic(self, request):
-        """概览页统计接口
+        """实例概览统计
         :param request: Request instance for DescribeInstanceStatistic.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeInstanceStatisticRequest`
         """
@@ -601,7 +649,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def AddClusterNode(self, request):
         """添加分片集群的节点。支持mongos和shard节点。
@@ -623,7 +672,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteClusterNode(self, request):
         """删除分片集群节点，只支持mongos节点。
@@ -645,10 +695,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeSlowLogDetail(self, request):
-        """DescribeSlowLogDetail
+        """查询实例运行慢日志
         :param request: Request instance for DescribeSlowLogDetail.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeSlowLogDetailRequest`
         """
@@ -667,10 +718,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeSlowLogStatistics(self, request):
-        """DescribeSlowLogStatistics
+        """实例运行慢日志统计
         :param request: Request instance for DescribeSlowLogStatistics.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeSlowLogStatisticsRequest`
         """
@@ -689,10 +741,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeSlowLogDatabase(self, request):
-        """DescribeSlowLogDatabase
+        """查询慢日志数据库列表
         :param request: Request instance for DescribeSlowLogDatabase.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeSlowLogDatabaseRequest`
         """
@@ -711,7 +764,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeSlowLogLineChart(self, request):
         """慢查询产生趋势折线图，反映慢查询趋势。
@@ -733,10 +787,11 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def UpdateMongoDBInstanceCluster(self, request):
-        """分片集群节点更配
+        """分片集群节点配置大小更配
         :param request: Request instance for UpdateMongoDBInstanceCluster.
         :type request: :class:`ksyun.client.mongodb.v20170101.models.UpdateMongoDBInstanceClusterRequest`
         """
@@ -755,7 +810,8 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeClusterForRestore(self, request):
         """查询分片集群可恢复配置
@@ -777,4 +833,188 @@ class MongodbClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
+
+    def DescribeDefaultParams(self, request):
+        """查询默认参数模板
+        :param request: Request instance for DescribeDefaultParams.
+        :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeDefaultParamsRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("DescribeDefaultParams", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(message=str(e))
+
+
+    def CreateParamGroup(self, request):
+        """创建参数组
+        :param request: Request instance for CreateParamGroup.
+        :type request: :class:`ksyun.client.mongodb.v20170101.models.CreateParamGroupRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("CreateParamGroup", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(message=str(e))
+
+
+    def DescribeParamGroupList(self, request):
+        """查询参数组列表
+        :param request: Request instance for DescribeParamGroupList.
+        :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeParamGroupListRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("DescribeParamGroupList", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(message=str(e))
+
+
+    def DescribeParamGroupInfo(self, request):
+        """查询参数组详情
+        :param request: Request instance for DescribeParamGroupInfo.
+        :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeParamGroupInfoRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("DescribeParamGroupInfo", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(message=str(e))
+
+
+    def DescribeModifyHistory(self, request):
+        """查询参数组修改历史
+        :param request: Request instance for DescribeModifyHistory.
+        :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeModifyHistoryRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("DescribeModifyHistory", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(message=str(e))
+
+
+    def DescribeInstanceParams(self, request):
+        """查询实例参数配置
+        :param request: Request instance for DescribeInstanceParams.
+        :type request: :class:`ksyun.client.mongodb.v20170101.models.DescribeInstanceParamsRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("DescribeInstanceParams", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(message=str(e))
+
+
+    def ModifyParamGroup(self, request):
+        """修改参数组
+        :param request: Request instance for ModifyParamGroup.
+        :type request: :class:`ksyun.client.mongodb.v20170101.models.ModifyParamGroupRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("ModifyParamGroup", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(message=str(e))
+
+
+    def DeleteParamGroup(self, request):
+        """删除参数组
+        :param request: Request instance for DeleteParamGroup.
+        :type request: :class:`ksyun.client.mongodb.v20170101.models.DeleteParamGroupRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("DeleteParamGroup", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(message=str(e))
